
.. _mapper_config_toplevel:

===============================
ORM Mapped Class Configuration
===============================

Detailed reference for ORM configuration, not including
relationships, which are detailed at
:ref:`relationship_config_toplevel`.

For a quick look at a typical ORM configuration, start with
:ref:`orm_quickstart`.

For an introduction to the concept of object relational mapping as implemented
in SQLAlchemy, it's first introduced in the :ref:`unified_tutorial` at
:ref:`tutorial_orm_table_metadata`.


.. toctree::
    :maxdepth: 3

    mapping_styles
    declarative_mapping
    dataclasses
    scalar_mapping
    inheritance
    nonstandard_mappings
    versioning
    mapping_api
